Introduction
============

Aioamqp library is a pure-Python implementation of the AMQP 0.9.1 protocol using `asyncio`.


Prerequisites
-------------

Aioamqp works only with python >= 3.3 using asyncio library.
If your are using Python 3.3 you'll have to install asyncio from pypi, but asyncio is now included in python 3.4 standard library.

Installation
------------

You can install the most recent aioamqp release from pypi using pip or easy_install:

 .. code-block:: shell

    pip install aioamqp
